#
# spec file for package newsbeuter
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           newsbeuter
Version:        2.9
Release:        5.1
Summary:        RSS/Atom Feed Reader for Text Terminals
License:        MIT
Group:          Productivity/Networking/Web/Browsers
Source:         http://www.newsbeuter.org/downloads/newsbeuter-%{version}.tar.gz
# pbleser: introduce OPTFLAGS make variable, instead of hard-coded -ggdb
Patch2:         newsbeuter-makefile.patch
# PATCH-FIX-UPSTREAM newsbeuter-ncurses6.patch zaitor@opensuse.org -- Fix build with ncurses 6 - patch taken from Fedora
Patch3:         newsbeuter-ncurses6.patch
# PATCH-FIX-UPSTREAM mvetter -- https://github.com/akrennmair/newsbeuter/commit/96e9506ae9e252c548665152d1b8968297128307
Patch4:         newsbeuter-2.9-CVE-2017-12904.patch
Url:            http://www.newsbeuter.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  libcurl-devel
BuildRequires:  libjson-c-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libstfl-devel
BuildRequires:  libxml2-devel
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  sqlite3-devel
BuildRequires:  zlib-devel
Recommends:     lynx
Recommends:     %{name}-lang

%description
Newsbeuter is an open-source RSS/Atom feed reader for text terminals. It runs
on Linux, FreeBSD, Mac OS X and other Unix-like operating
systems. Newsbeuter's great configurability and vast number of features make
it a perfect choice for people that need a slick and fast feed reader that can
be completely controlled via keyboard.

%lang_package

%prep
%setup -q
%patch2
%if 0%{?suse_version} > 1320
%patch3 -p1
%endif
%patch4 -p1

%build
./config.sh

%__make %{?jobs:-j%{jobs}} \
    	  prefix="%{_prefix}" \
    	  OPTFLAGS="%{optflags}"

%install
%makeinstall prefix="%{_prefix}"
%__chmod 0644 "%{buildroot}%{_mandir}"/*/*.*

%__mkdir RPM-DOC
%__mv "%{buildroot}%{_datadir}/doc/newsbeuter"/* RPM-DOC
/bin/rmdir "%{buildroot}%{_datadir}/doc/newsbeuter"

for l in zh; do
    %__rm -rf "%{buildroot}%{_datadir}/locale/${l}"
done

%find_lang newsbeuter

%files
%defattr(-,root,root)
%doc RPM-DOC/*
%doc AUTHORS CHANGES LICENSE README TODO
%{_bindir}/newsbeuter
%{_bindir}/podbeuter
%doc %{_mandir}/man1/newsbeuter.1%{ext_man}
%doc %{_mandir}/man1/podbeuter.1%{ext_man}

%files lang -f newsbeuter.lang

%changelog
* Thu Jan 18 2018 mvetter@suse.com
- bsc#1054578: Add newsbeuter-2.9-CVE-2017-12904.patch
  Fix improper neutralization of special elements used in an OS
  command in bookmarking function leading up to remote code execution.
* Tue Oct 13 2015 zaitor@opensuse.org
- Add newsbeuter-ncurses6.patch: Fix build with ncurses 6. Patch
  taken from Fedora. Apply only for openSUSE newer than 13.2.
* Thu Mar  5 2015 p.drouand@gmail.com
- Update to version 2.9
  * Fix custom keybindings in tag and filter selection dialogs (fixes #78).
  * Fix incorrect reloading of tags after editing the urls file.
  * Catch an exception that might be thrown by the "killfile" function.
  * Don't override feed titles for hidden feeds.
  * Fix dumpconfig.
  * Add support for FeedHQ (feedhq.org).
  * Fix missing variable in log output (fixes #124).
  * Fix type of configuration variables to path where appropriate (fixes #125).
  * Update to Brazilian Portuguese translation (fixes #126).
  * Fix crash when GUID is lost (fixes #127).
  * Fix dependency check (fixes #132).
  * Fix segfault in jump_to_next_unread_item (fixes #133).
  * Change code base to C++11.
  * Don't render inline images (fixes #154).
  * Fixed bug where feeds would appear empty due to variable shadowing issue.
- Remove merged patches
  * newsbeuter-ncurses.patch
  * newsbeuter-gcc47.patch
- Use download Url as source
- Remove obsolete conditional macros
- Split out translation files
- Remove depreciated/obsolete AUTHORS and %%clean sections
- Add libjson-c-devel build require; new upstream dependency
- Cleanup requirements list
* Sun Mar 25 2012 mrdocs@opensuse.org
  run -osc service localrun format_spec_file to fix copyright
* Wed Mar 21 2012 dimstar@opensuse.org
- Add newsbeuter-gcc47.patch: Fix build with gcc 4.7.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Feb  2 2011 pascal.bleser@opensuse.org
- update to 2.4:
  * support for query feeds in combination with Google Reader was added
  * it is now possible to configure proxy authentication methods
  * a quiet startup mode was added
  * overall memory usage was reduced by loading data from the cache only on
    demand
  * Bloglines support was removed
  * XDG Base Directory support was added
  * an authentication bug related to Google Reader was fixed
  * support for HTTP cookies was added
  * many small issues were fixed
* Thu Jun 24 2010 pascal.bleser@opensuse.org
- update to 2.3:
  * a number of miscellaneous bugs has been fixed, most notably the
    Google Reader authentication issue that came up when Google Reader
    changed its authentication scheme
- built against libstfl 0.21 (statically)
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- update to 2.2:
  * support for Google Reader was added
  * a great number of bugs were fixed
  * the killfile functionality was improved
  * article highlighting in the article list based on article content
    was added
  * a "hard quit" keybinding was added
  * an HTML table renderer was added
* Wed Dec 16 2009 mrueckert@suse.de
- just recommend lynx
* Wed Dec  9 2009 pascal.bleser@opensuse.org
- update to 2.1:
  * add support for 256 color terminal
  * the first article is now selected upon entering the article
    list
  * the selection is moved to the next feed when a feed is marked
    as read in the feed list
  * HTML rendering has been improved
  * add support for SOCKS proxies
  * add a new notification type, "notify-beep"
  * fixes various bugs
* Mon Apr 20 2009 pascal.bleser@opensuse.org
- update to 2.0
* Sun Aug 31 2008 guru@unixtech.be
- update to 1.1:
  * support for wrapping long header lines and links in the article
    view was added
  * a security issue where opening specially crafted URLs of articles
    could lead to execution of shell commands was fixed
* Wed Aug 20 2008 guru@unixtech.be
- new package
